@@ -27,6 +27,7 @@ PythonConsoleThemes = {
     ],
 }
 
+
 class KaaInterpreter(code.InteractiveInterpreter):
 
     def runcode(self, code):
@@ -66,7 +67,9 @@ class PythonConsoleMode(pythonmode.PythonMode):
         super().on_set_document(document)
         self.interp = KaaInterpreter()
 
-        self.document.append('Python %s\n' % sys.version, self.get_styleid('ps'))
+        self.document.append(
+            'Python %s\n' %
+            sys.version, self.get_styleid('ps'))
         self.document.append('>>>', self.get_styleid('ps'))
         self.document.append('\n', self.get_styleid('default'))
         p = self.document.endpos()
@@ -84,14 +87,14 @@ class PythonConsoleMode(pythonmode.PythonMode):
         wnd.cursor.setpos(f)
         self.document.undo.clear()
 
-    def put_string(self, wnd, s):
+    def put_string(self, wnd, s, overwrite=False):
         pos = wnd.cursor.pos
         f, t = self.document.marks['current_script']
         if not (f <= pos <= t):
             wnd.cursor.setpos(t)
             wnd.screen.selection.clear()
 
-        super().put_string(wnd, s)
+        super().put_string(wnd, s, overwrite)
 
     def replace_string(self, wnd, pos, posto, s, update_cursor=True):
         f, t = self.document.marks['current_script']
@@ -167,7 +170,7 @@ class PythonConsoleMode(pythonmode.PythonMode):
                 self.document.marks['current_script'] = (p, p)
                 wnd.cursor.setpos(p)
             else:
-                self._show_inputline(wnd, s+'\n')
+                self._show_inputline(wnd, s + '\n')
 
     def _show_inputline(self, wnd, s):
         doc = PythonInputlineMode.build(wnd, s)
@@ -182,6 +185,9 @@ class PythonConsoleMode(pythonmode.PythonMode):
         self.exec_script(wnd)
 
     def _put_script(self, wnd, text):
+        if text.endswith('\n'):
+            text = text[:-1]
+
         self.put_string(wnd, text)
         wnd.screen.selection.clear()
         hist = kaa.app.config.hist('pyconsole_script', self.MAX_HISTORY)
@@ -208,7 +214,7 @@ class PythonConsoleMode(pythonmode.PythonMode):
                 self._put_script(wnd, text)
 
         from kaa.ui.texthist import texthistmode
-        texthistmode.show_history('Search history:',callback, scripts)
+        texthistmode.show_history('Search history:', callback, scripts)
 
     @commandid('edit.paste')
     def paste(self, wnd):
@@ -270,8 +276,7 @@ class PythonInputlineMode(dialogmode.DialogMode, pythonmode.PythonMode):
 
     @classmethod
     def build(cls, target, s):
-        buf = document.Buffer()
-        doc = document.Document(buf)
+        doc = document.Document()
         doc.append(s)
         mode = cls()
         doc.setmode(mode)
@@ -280,8 +285,7 @@ class PythonInputlineMode(dialogmode.DialogMode, pythonmode.PythonMode):
 
 
 def show_console():
-    buf = document.Buffer()
-    cons = document.Document(buf)
+    cons = document.Document()
     mode = PythonConsoleMode()
     cons.setmode(mode)
     cons.set_title('<Python console>')
