@@ -26,16 +26,17 @@ class TestMacro(kaa_testutils._TestScreenBase):
         def f():
             pass
 
-        macro.record(f)
-        assert macro.get_commands() == [('command1', (), {})]
+        macro.record(1, f)
+        assert macro.get_commands() == [
+            (kaa.macro.rec_command, 1, 'command1', (), {})]
 
         @commandid('command2')
         @norec
         def g():
             pass
 
-        macro.record(g)
-        assert macro.get_commands() == [('command1', (), {})]
+        macro.record(1, g)
+        assert macro.get_commands() == [(kaa.macro.rec_command, 1, 'command1', (), {})]
 
     def test_run(self):
         wnd = self._getwnd("abc\ndef\n")
@@ -44,10 +45,10 @@ class TestMacro(kaa_testutils._TestScreenBase):
         macro.toggle_record()
 
         mode = wnd.document.mode
-        macro.record(mode.get_command('cursor.right')[1])
-        macro.record(mode.get_command('cursor.right')[1])
-        macro.record(mode.get_command('cursor.right')[1])
-        macro.record(mode.get_command('cursor.left')[1])
+        macro.record(1, mode.get_command('cursor.right')[1])
+        macro.record(1, mode.get_command('cursor.right')[1])
+        macro.record(1, mode.get_command('cursor.right')[1])
+        macro.record(1, mode.get_command('cursor.left')[1])
         macro.toggle_record()
 
         macro.run(wnd)
@@ -56,8 +57,8 @@ class TestMacro(kaa_testutils._TestScreenBase):
 
         macro.toggle_record()
 
-        macro.record_string('123')
-        macro.record_string('45')
+        macro.record_string('123', False)
+        macro.record_string('45', False)
         macro.toggle_record()
 
         macro.run(wnd)
